**********************************
The sherpa.astro.io.xstable module
**********************************

.. currentmodule:: sherpa.astro.io.xstable

.. automodule:: sherpa.astro.io.xstable

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      BaseParam
      Param

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      make_xstable_model
      write_xstable_model

Class Inheritance Diagram
=========================

.. inheritance-diagram:: BaseParam Param
   :parts: 1
